;------------------------------------------------------
;
; Advanced AutoLISP Concepts, CADENCE June 1992
; Bill Kramer
;
; Orthographic project construction lines
;
; Storage Lists
;  C_views ((ViewID P1 P2) ...)
;          ViewID 0 Front XY
;                 1 Side  ZY
;                 2 Top   XZ
;          P1/P2  Point limits of view
;
;------------------------------------------------------
;  Listing 1:
;  Create 3 View information list C_VIEWS.
;
(defun C:3VIEWS ( / p1 p2 id clyr)
  (setvar "CMDECHO" 0)
  (setq id 0
        c_views nil
        clyr (getvar "CLAYER"))
  (repeat 3
     (cond
       ((= id 0) (prompt "\nFront View: "))
       ((= id 1) (prompt "\nSide View: "))
       ((= id 2) (prompt "\nTop View: "))
       (t (prompt "\n3VIEWS ERROR!")))
     (setq c_views
       (cons
          (list id
                (setq p1 (getpoint "\nLocate bottom left: "))
                (setq p2 (getcorner p1 "\n       top right: ")))
          c_views))
     (command ".Layer" "M" (strcat "CLINE" (itoa id))
                       "C" "BLUE" "" ""
              ".Pline" p1 (list (car p1) (cadr p2))
                       p2 (list (car p2) (cadr p1)) "C")
     (setq id (1+ id))

  )
  (setq c_views (reverse c_views))
  (command ".Layer" "S" clyr "")
  (princ)
)
;
;------------------------------------------------------
;  Listing 2:
;  Create Project point data into other views.
;
(defun C:PRO ()
  (setq pt (getpoint "\nPick a point in any view: ")
        viewid (viewfind pt)
        pt (viewpt_to_w viewid pt))
  (cond
    ((= viewid 0) ;; In front view
      (draw_c_line 1 1 (cadr pt))
      (draw_c_Line 2 0 (car pt))
    )
    ((= viewid 1) ;; In side view
      (draw_c_line 0 1 (cadr pt))
      (draw_c_line 2 1 (car pt))
    )
    ((= viewid 2) ;; In top view
      (draw_c_line 0 0 (car pt))
      (draw_c_line 1 0 (cadr pt))
    )
    (t (prompt "\nPRO ERROR in view id."))
  )
  (princ)
)
;
;------------------------------------------------------
; Listing 3:
; Determine which viewport a point is inside of.
;
(defun VIEWFIND (pt / viewdata found)
  (foreach viewdata c_views
     (if (and (<= (caadr viewdata) (car pt) (caaddr viewdata))
              (<= (cadadr viewdata) (cadr pt) (cadadr (cdr viewdata))))
         (setq found (car viewdata))
     )
  )
  found
)
;------------------------------------------------------
;  Listing 4:
;  Convert view input point into world coordinates.
;
(defun VIEWPT_TO_W (viewid pt)
  (mapcar '- pt (cadr (assoc viewid c_views))))
;
;
;------------------------------------------------------
;  Listing 5:
;  Draw a construction line inside of a view.
;    viewid = view number {0, 1, 2}
;    Ord = AutoCAD axis inside the view, 0 for X, 1 for Y.
;    Val = real world ordinate value.
;
(defun DRAW_C_LINE (viewid ord val)
  (entmake
     (list
       (cons 0 "LINE")
       (cons 8 (strcat "CLINE" (itoa viewid)))
       (if (= ord 0) ;;; Along X drawing axis
          (list 10
             (+ val (caadr (assoc viewid c_views)))
             (cadadr (assoc viewid c_views))
             0.0)
          ;;; else along Y axis
          (list 10
             (caadr (assoc viewid c_views))
             (+ val (cadadr (assoc viewid c_views)))
             0.0)
       )
       (if (= ord 0) ;;; Along X drawing axis
          (list 11
             (+ val (caadr (assoc viewid c_views)))
             (cadadr (cdr (assoc viewid c_views)))
             0.0)
          (list 11
             (caaddr (assoc viewid c_views))
             (+ val (cadadr (assoc viewid c_views)))
             0.0)
       )
     )
  )
)
;------------------------------------------------------
;  Listing 6:
;  Clear the construction line graphics in a view.
;
(defun C:VCLEAR ( / pt viewid ss1)
  (initget 1)
  (setq pt (getpoint "\nLocate a point in the view to clear: ")
        viewid (viewfind pt)
        ss1 (ssget "X" (list (cons 8 (strcat "CLINE" (itoa viewid)))
                             (cons 0 "LINE"))))
  (if ss1 (command ".Erase" ss1 "" "Redraw"))
  (princ)
)
;
